@@ -1,10 +1,10 @@
-__version__ = "0.0.2"
+__version__ = "0.0.4"
 # lac tokenizer를 활용한 중국어 키워드 추출 전용 tokenizer 개발
 
 
 # basic utils
 from .data_utils import Doc, Token
-from .process_utils import Tokenization, TokenCandidateGeneration
+from .process_utils import Tokenization, TokenCandidateGeneration, ZhPreprocessing
 
 # lac-tokenizer based chinese keyphrase extractor
 from .tokenization_zh import LACTokenization
\ No newline at end of file
