@@ -32,15 +32,22 @@ class Token:
     
     Args:
         DocId: Unique id for the example. 
-        offset: Index of this token in the parent Document.
-        text: The raw text of Token.
+        offset: Char-level position of the token in parent Document.
+                If offset is integer use offset and size to indexing the token in original document.
+                If offset is list use list to indexing the token int original document.
+        text: The raw text of Token. 
         pos: Part-of-speeches after tokenizing.
     """
     DocId: str
-    offset: int
+    offset: Union[int, List]
     text: str
     pos: str
-        
+    
+    @property
+    def size(self):
+        """offset과 size를 활용하여 이 토큰이 원래 Document에 어디에 위치하는지 알 수 있음."""
+        return len(self.text)
+    
     def to_json_string(self):
         """Serializes this instance to a JSON string."""
         return json.dumps(dataclasses.asdict(self)) + "\n"
@@ -59,6 +66,11 @@ class Doc:
     text: str
     tokens: List[Token]
         
+    @property
+    def size(self):
+        """Size of Document"""
+        return len(self.text)
+        
     def to_json_string(self):
         """Serializes this instance to a JSON string."""
         return json.dumps(dataclasses.asdict(self), indent=2) + "\n"
